# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.predictor_api import PredictorApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestPredictorApi(unittest.TestCase):
    """PredictorApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.predictor_api.PredictorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_predictor_check(self):
        """Test case for predictor_check

        Проверка механизма подсказки временных окон.  # noqa: E501
        """
        pass

    def test_predictor_insert(self):
        """Test case for predictor_insert

        Добавление нового заказа.  # noqa: E501
        """
        pass

    def test_predictor_predict(self):
        """Test case for predictor_predict

        Подсказка временного окна  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
