# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.cargo import Cargo  # noqa: E501
from vrt_ud.rest import ApiException

class TestCargo(unittest.TestCase):
    """Cargo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Cargo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.cargo.Cargo()  # noqa: E501
        if include_optional :
            return Cargo(
                key = 'cargo01', 
                capacity = vrt_ud.models.capacity.Capacity(
                    mass = 10, 
                    volume = 2, 
                    capacity_x = 1, 
                    capacity_y = 2, 
                    capacity_z = 3, ), 
                width = 1, 
                height = 0.3, 
                length = 2.2, 
                max_storage_time = 45, 
                restrictions = ["Freezer"]
            )
        else :
            return Cargo(
                key = 'cargo01',
                capacity = vrt_ud.models.capacity.Capacity(
                    mass = 10, 
                    volume = 2, 
                    capacity_x = 1, 
                    capacity_y = 2, 
                    capacity_z = 3, ),
        )

    def testCargo(self):
        """Test Cargo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
