# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_ud
from vrt_ud.api.data_api import DataApi  # noqa: E501
from vrt_ud.rest import ApiException


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = vrt_ud.api.data_api.DataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_clean_data(self):
        """Test case for clean_data

        Удаление данных за временной промежуток  # noqa: E501
        """
        pass

    def test_download_photo(self):
        """Test case for download_photo

        Скачивание фотографии по id  # noqa: E501
        """
        pass

    def test_find_photos(self):
        """Test case for find_photos

        Получение идентификаторов фотографий по фильтру  # noqa: E501
        """
        pass

    def test_load_data(self):
        """Test case for load_data

        Загрузка данных из файла в виде base64 строки  # noqa: E501
        """
        pass

    def test_load_data_file(self):
        """Test case for load_data_file

        Загрузка данных из файла  # noqa: E501
        """
        pass

    def test_read_orders(self):
        """Test case for read_orders

        Получение заказа по фильтру  # noqa: E501
        """
        pass

    def test_remove_orders(self):
        """Test case for remove_orders

        Удаление заказов по фильтру  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
