# coding: utf-8

"""
    VeeRoute Urban Delivery API

    Программный интерфейс продукта Urban Delivery  # noqa: E501

    The version of the OpenAPI document: 2.7.159116
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_ud
from vrt_ud.models.tracks_result import TracksResult  # noqa: E501
from vrt_ud.rest import ApiException

class TestTracksResult(unittest.TestCase):
    """TracksResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TracksResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_ud.models.tracks_result.TracksResult()  # noqa: E501
        if include_optional :
            return TracksResult(
                tracks = [
                    vrt_ud.models.performer_track.PerformerTrack(
                        shift_key = 'performer01', 
                        points = [
                            vrt_ud.models.track_point.TrackPoint(
                                latitude = 55.692789, 
                                longitude = 37.554554, 
                                timestamp = 56, )
                            ], 
                        last_point = vrt_ud.models.track_point.TrackPoint(
                            latitude = 55.692789, 
                            longitude = 37.554554, 
                            timestamp = 56, ), )
                    ]
            )
        else :
            return TracksResult(
        )

    def testTracksResult(self):
        """Test TracksResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
